@@ -26,7 +26,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 class Q_DECL_EXPORT SimpleIpV6AddressValidator : public QValidator
 {
 public:
-    explicit SimpleIpV6AddressValidator(QObject *parent);
+    enum AddressStyle {Base, WithCidr, WithPort};
+
+    explicit SimpleIpV6AddressValidator(QObject *parent, AddressStyle style = AddressStyle::Base);
     ~SimpleIpV6AddressValidator() override;
 
     State validate(QString &, int &) const override;
@@ -38,6 +40,9 @@ public:
      *  In the tetrads are placed into QList. Input string may be changed.
      */
     QValidator::State checkTetradsRanges(QString &) const;
+private:
+    AddressStyle m_addressStyle;
+    QRegularExpressionValidator m_validator;
 };
 
 #endif // SIMPLEIPV6ADDRESSVALIDATOR_H
